"""fmt command."""
import subprocess

import click


@click.command()
@click.option(
    "--version",
    "version",
    is_flag=True,
    default=False,
    help="Print black version and exit.",
)
def fmt(*, version: bool) -> None:
    """Format all files of the current project using `black`."""
    root_args = ["black"]
    if version:
        root_args.append("--version")
        subprocess.run(args=root_args)



"""lock command."""
import click

from pyrgo import _pyrgo


@click.command()
def lock() -> None:
    """Lock dependencies."""
    pyproject_content = _pyrgo.read_pyproject()
    click.echo(pyproject_content)



"""activate command."""

import pathlib
import sys
from venv import create

import click


def _create_virtual_env(venv_dir: pathlib.Path) -> None:
    create(env_dir=venv_dir)
    click.echo(message=".venv has been created.")


ACTIVATION_MSG: str = (
    "\n```\nTo activate the virtual env run:\n\n"
    "On Windows, run:\n`.venv\\Scripts\\activate.bat`\n\n"
    "On Unix or MacOS, run:\n`source .venv/bin/activate`\n```\n"
)


@click.command
def venv() -> None:
    """Create project virtual environment."""
    cwd = pathlib.Path().cwd()
    venv_dir = cwd.joinpath(".venv")
    if venv_dir.exists():
        if venv_dir.is_dir():
            click.echo(message=".venv already exists.")
            click.echo(ACTIVATION_MSG)

        elif venv_dir.is_file():
            pathlib.Path.unlink(venv_dir)
            _create_virtual_env(venv_dir)
            click.echo(ACTIVATION_MSG)

        else:
            click.echo(".venv for is neither a directory nor a file.")
            sys.exit(1)

    else:
        _create_virtual_env(venv_dir=venv_dir)
        click.echo(ACTIVATION_MSG)



"""New release."""
import pathlib

import tomli
from urllib.parse import urlencode

import webbrowser


def project_version(cwd: pathlib.Path) -> str:
    """Read `Cargo.toml` current package version."""
    try:
        cargo_toml = tomli.loads(
            cwd.joinpath(
                "Cargo.toml",
            ).read_text(encoding="utf-8"),
        )
    except FileNotFoundError:
        raise
    except Exception:
        raise

    return cargo_toml["package"]["version"]


def project_source(cwd: pathlib.Path) -> str:
    """Read `Source` from `pyproject.toml`."""
    try:
        pyproject_toml = tomli.loads(
            cwd.joinpath(
                "pyproject.toml",
            ).read_text(encoding="utf-8"),
        )
    except FileNotFoundError:
        raise
    except Exception:
        raise

    return pyproject_toml["project"]["urls"]["Source"]


def main() -> None:
    """Prepare new release."""
    cwd = pathlib.Path().cwd()
    version = project_version(cwd=cwd)
    params = urlencode(
        query={
            "title": f"v{version}",
            "tag": f"v{version}",
        },
    )
    package_source = project_source(cwd=cwd)

    webbrowser.open_new_tab(url=f"{package_source}/releases/new?{params}")


if __name__ == "__main__":
    main()



"""Root CLI."""
import click

from pyrgo.command.check import check
from pyrgo.command.clean import clean
from pyrgo.command.fmt import fmt
from pyrgo.command.lock import lock
from pyrgo.command.venv import venv


@click.group()
@click.version_option()
def cli() -> None:
    """pyrgo. Python package manager."""


cli.add_command(cmd=fmt, name="fmt")
cli.add_command(cmd=lock, name="lock")
cli.add_command(cmd=check, name="check")
cli.add_command(cmd=venv, name="venv")
cli.add_command(cmd=clean, name="clean")
